@@ -23,8 +23,7 @@ def distance(origin: Tuple[float, float], destination: Tuple[float, float]) -> f
     """Calculate the Haversine distance in meters."""
     radius = 6372797.560856  # Earth's quatratic mean radius for WGS-84
 
-    lat1, lon1, lat2, lon2 = map(
-        math.radians, [origin[0], origin[1], destination[0], destination[1]])
+    lat1, lon1, lat2, lon2 = map(math.radians, [origin[0], origin[1], destination[0], destination[1]])
 
     dlon = lon2 - lon1
     dlat = lat2 - lat1
